@@ -31,6 +31,22 @@ class Output;
 class Config;
 }
 
+namespace QmlScreen {
+    typedef enum {
+        Recent = 0,
+        Horizontal,
+        Vertical,
+        None,
+        All
+    }type;
+
+    struct RectangleDistance{
+        type m_type;
+        float m_distance;
+    };
+}
+using namespace QmlScreen;
+
 class QMLScreen : public QQuickItem
 {
     Q_OBJECT
@@ -51,14 +67,14 @@ class QMLScreen : public QQuickItem
                READ outputScale
                NOTIFY outputScaleChanged)
 
-  public:
+public:
     explicit QMLScreen(QQuickItem *parent = nullptr);
     ~QMLScreen() override;
 
     int connectedOutputsCount() const;
     int enabledOutputsCount() const;
 
-    QMLOutput* primaryOutput() const;
+    QMLOutput *primaryOutput() const;
     QList<QMLOutput*> outputs() const;
 
     QSize maxScreenSize() const;
@@ -72,17 +88,26 @@ class QMLScreen : public QQuickItem
 
     void setActiveOutput(QMLOutput *output);
 
-    void setScreenPos(QMLOutput *output);
-
-  public Q_SLOTS:
-    void setActiveOutput() {
-        setActiveOutput(qobject_cast<QMLOutput*>(sender()));
-    }
-    void setScreenPos() {
-        setScreenPos(qobject_cast<QMLOutput*>(sender()));
+    void setScreenPos(QMLOutput *output, bool isReleased);
+    void setScreenPosMulti(int connectScreenNum);
+    void setScreenCenterPos();
+    struct RectangleDistance calculateRectangleDistance(QMLOutput *qmlOutput1, QMLOutput *qmlOutput2);
+    void resetOutputPos(QMLOutput *output, type m_type, QMLOutput *outputRef);
+    
+public Q_SLOTS:
+    void setActiveOutput()
+    {
+        setActiveOutput(qobject_cast<QMLOutput *>(sender()));
     }
 
-  Q_SIGNALS:
+    void setActiveOutputByCombox(int screenId);
+    void setScreenPos(bool isReleased)
+    {
+        setScreenPos(qobject_cast<QMLOutput*>(sender()), isReleased);
+    }
+    void getClickedPos();
+
+Q_SIGNALS:
     void connectedOutputsCountChanged();
     void enabledOutputsCountChanged();
 
@@ -90,7 +115,9 @@ class QMLScreen : public QQuickItem
 
     void focusedOutputChanged(QMLOutput *output);
 
-  private Q_SLOTS:
+    void released();
+
+private Q_SLOTS:
     void addOutput(const KScreen::OutputPtr &output);
     void removeOutput(int outputId);
 
@@ -100,24 +127,23 @@ class QMLScreen : public QQuickItem
 
     void viewSizeChanged();
 
-  private:
+private:
     void qmlOutputMoved(QMLOutput *qmlOutput);
     void updateCornerOutputs();
     void setOutputScale(float scale);
 
     KScreen::ConfigPtr m_config;
-    QHash<KScreen::OutputPtr,QMLOutput*> m_outputMap;
+    QHash<KScreen::OutputPtr, QMLOutput *> m_outputMap;
     QVector<QMLOutput*> m_manuallyMovedOutputs;
     int m_connectedOutputsCount = 0;
     int m_enabledOutputsCount = 0;
 
-    float m_outputScale = 1.0 / 8.0;//缩放比例
-
-    QMLOutput *m_leftmost = nullptr;
-    QMLOutput *m_topmost = nullptr;
-    QMLOutput *m_rightmost = nullptr;
-    QMLOutput *m_bottommost = nullptr;
+    float m_outputScale = 1.0 / 14.0;// 缩放比例
 
+    QList<qreal> leftPosList;
+    QList<qreal> rightPosList;
+    qreal leftX = 0.0;
+    qreal topY  = 0.0;
 };
 
 #endif // QMLSCREEN_H
