@@ -1,11 +1,10 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
- *
- * Copyright (C) 2019 Tianjin KYLIN Information Technology Co., Ltd.
+/*
+ * Copyright (C) 2023, KylinSoft Co., Ltd.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * the Free Software Foundation; either version 3, or (at your option)
+ * any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,10 +12,9 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
- */
+**/
 #ifndef LEFTWIDGETITEM_H
 #define LEFTWIDGETITEM_H
 
@@ -25,6 +23,7 @@
 #include <QHBoxLayout>
 #include <QSvgRenderer>
 #include <QPixmap>
+#include <QResizeEvent>
 
 class LeftWidgetItem : public QWidget
 {
@@ -44,18 +43,23 @@ public:
 
     QString text();
 
-private:
-    // load svg picture
+    // Load svg picture
     const QPixmap loadSvg(const QString &fileName, QString color);
-    // chang svg picture's color
+    // Chang svg picture's color
     QPixmap drawSymbolicColoredPixmap(const QPixmap &source, QString cgcolor);
 
+protected:
+    void resizeEvent(QResizeEvent *event);
+
+private slots:
+    void changedLabelSlot();
 private:
     QLabel * iconLabel;
     QLabel * textLabel;
 
     QWidget * widget;
     QString icoName;
+    QString mStr;
 
 };
 
